@@ -1,3 +1,6 @@
+# -*- coding: utf-8 -*-
+# Copyright (C) 2012 Anaconda, Inc
+# SPDX-License-Identifier: BSD-3-Clause
 from __future__ import absolute_import
 
 from os.path import basename
@@ -11,19 +14,8 @@ from conda.models.channel import Channel, prioritize_channels
 def install(prefix, specs, args, env, *_, **kwargs):
     # TODO: support all various ways this happens
     # Including 'nodefaults' in the channels list disables the defaults
-    new_specs = []
-    channel_urls = set()
-    for elem in specs:
-        if "::" in elem:
-            channel_urls.add(elem.split("::")[0])
-            new_specs.append(elem.split("::")[-1])
-        else:
-            new_specs.append(elem)
-    specs = new_specs
-    channel_urls = list(channel_urls)
-    # TODO: support all various ways this happens
-    # Including 'nodefaults' in the channels list disables the defaults
-    channel_urls = channel_urls + [chan for chan in env.channels if chan != 'nodefaults']
+    channel_urls = [chan for chan in env.channels if chan != 'nodefaults']
+
     if 'nodefaults' not in env.channels:
         channel_urls.extend(context.channels)
     _channel_priority_map = prioritize_channels(channel_urls)
